Re: [PATCH V1] usb: Fix typo in comment

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On 19.12.2022 3.38, Gongwei Li wrote:
From: Gongwei Li <ligongwei@xxxxxxxxxx>

Spelling mistake in comment.

Signed-off-by: Gongwei Li <ligongwei@xxxxxxxxxx>
---
  drivers/usb/host/pci-quirks.c | 4 ++--
  1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/usb/host/pci-quirks.c b/drivers/usb/host/pci-quirks.c
index ef08d68b9714..9710425e69aa 100644
--- a/drivers/usb/host/pci-quirks.c
+++ b/drivers/usb/host/pci-quirks.c
@@ -1103,10 +1103,10 @@ void usb_enable_intel_xhci_ports(struct pci_dev *xhci_pdev)
  	pci_read_config_dword(xhci_pdev, USB_INTEL_USB2PRM,
  			&ports_available);
- dev_dbg(&xhci_pdev->dev, "Configurable USB 2.0 ports to hand over to xCHI: 0x%x\n",
+	dev_dbg(&xhci_pdev->dev, "Configurable USB 2.0 ports to hand over to xHCI: 0x%x\n",
  			ports_available);
  /* Write XUSB2PR, the xHC USB 2.0 Port Routing Register, to

xHC isn't a typo in this case, just refers to the actual xHC Extensible Host Controller itself.
The port routing register isn't part of the  xHCI specification.

Thanks
-Mathias
@@ -1103,10 +1103,10 @@ void usb_enable_intel_xhci_ports(struct pci_dev *xhci_pdev)
  			ports_available);
- /* Write XUSB2PR, the xHC USB 2.0 Port Routing Register, to
+	/* Write XUSB2PR, the xHCI USB 2.0 Port Routing Register, to

xHC isn't a typo in this case, just refers to the actual xHC Extensible Host Controller itself.





[Index of Archives]     [Linux Media]     [Linux Input]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]     [Old Linux USB Devel Archive]

  Powered by Linux